==> helidon-docs-1.3.0.jar: pages/guides/01_overview.js <==
<doc-view>

<h2 id="_getting_started">Getting Started</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/02_quickstart-se"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Quickstart SE</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create your first Helidon SE application in under 5 minutes.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/03_quickstart-mp"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Quickstart MP</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create your first Helidon MP application in under 5 minutes.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_basics">Basics</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/07_health_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Health Check Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon MP built-in and custom health checks.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/07_health_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Health Check Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon SE built-in and custom health checks.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/09_metrics_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Metrics Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon MP built-in and application metrics.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/09_metrics_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Metrics Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon SE built-in and application metrics.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/11_config_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Config Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure a Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/11_config_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Config Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure a Helidon SE application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_persistence">Persistence</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/20_datasource"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using DataSources</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use DataSources
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/22_jta"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using Transactions</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use Java Transaction API (JTA)-compliant transactions
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/24_jpa"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using JPA</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use the Java Persistence API (JPA)
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_build_and_deploy">Build and Deploy</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/30_dockerfile"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Creating Docker Images</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to package your application and the necessary runtime dependencies as
a Docker image.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/32_jib"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Building Container Images with Jib</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Jib to create a container image without Docker.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/34_Oracle_Kubernetes"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Deploying to OKE</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to deploy your application to Oracle Cloud Infrastructure Container
Engine for Kubernetes (OKE).</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/36_graalnative"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Building Native Images with GraalVM</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use GraalVM to build a native executable for your Helidon SE application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_tutorials">Tutorials</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/91_mp-tutorial"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Helidion MP Tutorial</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to build an Helidon MicroProfile (MP) application from scratch.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>
</doc-view>

==> helidon-docs-1.4.4.jar: pages/guides/01_overview.js <==
<doc-view>

<h2 id="_getting_started">Getting Started</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/02_quickstart-se"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Quickstart SE</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create your first Helidon SE application in under 5 minutes.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/03_quickstart-mp"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Quickstart MP</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Create your first Helidon MP application in under 5 minutes.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_basics">Basics</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/07_health_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Health Check Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon MP built-in and custom health checks.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/07_health_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Health Check Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon SE built-in and custom health checks.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/09_metrics_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Metrics Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon MP built-in and application metrics.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/09_metrics_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Metrics Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Helidon SE built-in and application metrics.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/11_config_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Config Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure a Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/11_config_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Config Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure a Helidon SE application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/12_tracing_mp_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">MP Tracing Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to trace a Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/12_tracing_se_guide"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">SE Tracing Guide</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to trace a Helidon SE application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_persistence">Persistence</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/20_datasource"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using DataSources</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use DataSources
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/22_jta"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using Transactions</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use Java Transaction API (JTA)-compliant transactions
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/24_jpa"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Using JPA</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to configure and use the Java Persistence API (JPA)
in your Helidon MP application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_build_and_deploy">Build and Deploy</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/30_dockerfile"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Creating Docker Images</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to package your application and the necessary runtime dependencies as
a Docker image.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/32_jib"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Building Container Images with Jib</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use Jib to create a container image without Docker.</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/34_Oracle_Kubernetes"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Deploying to OKE</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to deploy your application to Oracle Cloud Infrastructure Container
Engine for Kubernetes (OKE).</p>
</v-card-text>
</v-card>
</v-flex>
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/36_graalnative"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Building Native Images with GraalVM</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to use GraalVM to build a native executable for your Helidon SE application.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>

<h2 id="_tutorials">Tutorials</h2>
<div class="section">
<v-layout row wrap class="mb-5">
<v-flex xs12>
<v-container fluid grid-list-md class="pa-0">
<v-layout row wrap class="pillars">
<v-flex xs12 sm4 lg3>
<v-card>
<router-link to="/guides/91_mp-tutorial"><div class="card__link-hover"/>
</router-link>
<v-card-title primary class="headline layout justify-center">
<span style="text-align:center">Helidon MP Tutorial</span>
</v-card-title>
<v-card-text class="caption">
<p></p>
<p>Learn how to build a Helidon MicroProfile (MP) application from scratch.</p>
</v-card-text>
</v-card>
</v-flex>
</v-layout>
</v-container>
</v-flex>
</v-layout>
</div>
</doc-view>
